@@ -1,5 +1,5 @@
 USERS_COLS_CONCISE <- c("user_id", "user_name", "status")
-USERS_COLS <- c("user_id", "email", "user_name", "active_workspace", "default_workspace", "status")
+USERS_COLS <- c("user_id", "email", "user_name", "memberships", "active_workspace", "default_workspace", "status")
 
 test_that("get active users", {
   skip_on_cran()
